#
# spec file for package python-tldextract
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-tldextract
Version:        2.2.1
Release:        2.1
Summary:        Python module to separate the TLD of a URL
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/john-kurkowski/tldextract
Source:         https://files.pythonhosted.org/packages/source/t/tldextract/tldextract-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
# No internet connection on OBS build hosts; skip suffix list snapshot diff
Patch:          tldextract-tests-offline.patch
### BEGIN test requirements
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-file} >= 1.4
BuildRequires:  %{python_module requests} >= 2.1.0
BuildRequires:  %{python_module responses}
### END test requirements
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-idna >= 2.1.0
Requires:       python-requests >= 2.1.0
Requires:       python-requests-file >= 1.4
Obsoletes:      python-tldextract <= 2.0.1
BuildArch:      noarch

%python_subpackages

%description
tldextract accurately separates the gTLD or ccTLD (generic or country code
top-level domain) from the registered domain and subdomains of a URL, using the
Public Suffix List. By default, this includes the public ICANN TLDs and their
exceptions. You can optionally support the Public Suffix List's private domains
as well.

%prep
%setup -q -n tldextract-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec setup.py develop --user
%python_exec -m pytest -v tests

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/*
%python3_only %{_bindir}/tldextract

%changelog
* Sun Mar 10 2019 9+suse@cirno.systems
- Run test suite
- Add tldextract-tests-offline.patch
  No internet connection on OBS build hosts; skip suffix list
  snapshot diff
- Update to 2.2.1
  * Bugfixes
  - Ignore case on punycode prefix check
  - Drop support for EOL Python 2.6
  - Improve sundry doc and README bits
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Mon Apr 16 2018 jengelh@inai.de
- Update summary.
* Tue Feb  6 2018 9+suse@cirno.systems
- Convert to singlespec, fix non-SPDX license tag
- Add rpmlintrc for (required) hidden file
- Add README.md to docs and use %%license macro
- Update to 2.2.0
  * Bugfixes:
  - Switch to explicit Python version check
  - Work around `pkg_resources` missing
  - Always close sessions
  * Features:
  - Add `fqdn` and `ipv4` convenience properties
  - Add `cache_fetch_timeout` kwarg
    and `TLDEXTRACT_CACHE_TIMEOUT` env var
  * Misc:
  - Document public vs. private domains
  - Document support for Python 3.6
* Fri Jun 24 2016 archie.cobbs@gmail.com
- Correct license in spec file (MIT -> BSD)
* Sun Jun 19 2016 archie.cobbs@gmail.com
- Fix homepage URL in specfile
* Tue Jun 14 2016 archie.cobbs@gmail.com
- Initial creation of package, version 2.0.1
